==> xlniuxdata-vipgame-1.0.65-20170105.024607-60-sources.jar: com/xunlei/niux/data/vipgame/dto/customerService/CsCallerDTO.java <==
package com.xunlei.niux.data.vipgame.dto.customerService;

/**
 * Created by zhangya on 2016/12/22.
 */
public class CsCallerDTO {

    private Long demandId;
    private String demandName;
    private String gameId;
    private String type;
    private String rule;
    private String backflow;
    private String beginTime;
    private String endTime;
    private Integer total;
    private String remark;
    private String fromBeginTime;
    private String toBeginTime;
    private String inputBy;
    private String inputTime;
    private String phone;

    private Long seqid;
    private Long userId;
    private Long orderNo;
    private Integer answer;
    private Integer accept;
    private String feedback;
    private String editTime;
    private String editBy;
    private String lastCallTime;
    private Integer status;

    private Integer loginTime;
    private Integer payTotal;

    private Long fromSeqid;
    private Long toSeqid;
    private Integer days;


    public Integer getDays() {
        return days;
    }

    public void setDays(Integer days) {
        this.days = days;
    }

    public Long getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(Long orderNo) {
        this.orderNo = orderNo;
    }

    public Long getFromSeqid() {
        return fromSeqid;
    }

    public void setFromSeqid(Long fromSeqid) {
        this.fromSeqid = fromSeqid;
    }

    public Long getToSeqid() {
        return toSeqid;
    }

    public void setToSeqid(Long toSeqid) {
        this.toSeqid = toSeqid;
    }

    public Integer getLoginTime() {
        return loginTime;
    }

    public void setLoginTime(Integer loginTime) {
        this.loginTime = loginTime;
    }

    public Integer getPayTotal() {
        return payTotal;
    }

    public void setPayTotal(Integer payTotal) {
        this.payTotal = payTotal;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public String getFromBeginTime() {
        return fromBeginTime;
    }

    public void setFromBeginTime(String fromBeginTime) {
        this.fromBeginTime = fromBeginTime;
    }

    public String getToBeginTime() {
        return toBeginTime;
    }

    public void setToBeginTime(String toBeginTime) {
        this.toBeginTime = toBeginTime;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public Long getDemandId() {
        return demandId;
    }

    public void setDemandId(Long demandId) {
        this.demandId = demandId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getDemandName() {
        return demandName;
    }

    public void setDemandName(String demandName) {
        this.demandName = demandName;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public String getBackflow() {
        return backflow;
    }

    public void setBackflow(String backflow) {
        this.backflow = backflow;
    }

    public String getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(String beginTime) {
        this.beginTime = beginTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getAnswer() {
        return answer;
    }

    public void setAnswer(Integer answer) {
        this.answer = answer;
    }

    public Integer getAccept() {
        return accept;
    }

    public void setAccept(Integer accept) {
        this.accept = accept;
    }

    public String getFeedback() {
        return feedback;
    }

    public void setFeedback(String feedback) {
        this.feedback = feedback;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }
}

==> xlniuxdata-vipgame-1.0.65-20170417.151341-72-sources.jar: com/xunlei/niux/data/vipgame/dto/customerService/CsCallerDTO.java <==
package com.xunlei.niux.data.vipgame.dto.customerService;

/**
 * Created by zhangya on 2016/12/22.
 */
public class CsCallerDTO {

    private Long demandId;
    private String demandName;
    private String gameId;
    private String type;
    private String rule;
    private String backflow;
    private String beginTime;
    private String endTime;
    private Integer total;
    private String remark;
    private String fromBeginTime;
    private String toBeginTime;
    private String inputBy;
    private String inputTime;
    private String phone;

    private Long seqid;
    private Long userId;
    private Long orderNo;
    private Integer answer;
    private Integer accept;
    private String feedback;
    private String editTime;
    private String editBy;
    private String lastCallTime;
    private Integer status;

    private Integer loginTime;
    private Integer payTotal;

    private Long fromSeqid;
    private Long toSeqid;
    private Integer days;

    private String userName;
    private Integer feedbackType;

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public Integer getFeedbackType() {
        return feedbackType;
    }

    public void setFeedbackType(Integer feedbackType) {
        this.feedbackType = feedbackType;
    }

    public Integer getDays() {
        return days;
    }

    public void setDays(Integer days) {
        this.days = days;
    }

    public Long getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(Long orderNo) {
        this.orderNo = orderNo;
    }

    public Long getFromSeqid() {
        return fromSeqid;
    }

    public void setFromSeqid(Long fromSeqid) {
        this.fromSeqid = fromSeqid;
    }

    public Long getToSeqid() {
        return toSeqid;
    }

    public void setToSeqid(Long toSeqid) {
        this.toSeqid = toSeqid;
    }

    public Integer getLoginTime() {
        return loginTime;
    }

    public void setLoginTime(Integer loginTime) {
        this.loginTime = loginTime;
    }

    public Integer getPayTotal() {
        return payTotal;
    }

    public void setPayTotal(Integer payTotal) {
        this.payTotal = payTotal;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public String getFromBeginTime() {
        return fromBeginTime;
    }

    public void setFromBeginTime(String fromBeginTime) {
        this.fromBeginTime = fromBeginTime;
    }

    public String getToBeginTime() {
        return toBeginTime;
    }

    public void setToBeginTime(String toBeginTime) {
        this.toBeginTime = toBeginTime;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public Long getDemandId() {
        return demandId;
    }

    public void setDemandId(Long demandId) {
        this.demandId = demandId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getDemandName() {
        return demandName;
    }

    public void setDemandName(String demandName) {
        this.demandName = demandName;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public String getBackflow() {
        return backflow;
    }

    public void setBackflow(String backflow) {
        this.backflow = backflow;
    }

    public String getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(String beginTime) {
        this.beginTime = beginTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getAnswer() {
        return answer;
    }

    public void setAnswer(Integer answer) {
        this.answer = answer;
    }

    public Integer getAccept() {
        return accept;
    }

    public void setAccept(Integer accept) {
        this.accept = accept;
    }

    public String getFeedback() {
        return feedback;
    }

    public void setFeedback(String feedback) {
        this.feedback = feedback;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }
}
